from typing import Any, Dict, Type, TypeVar

from typing import List


from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Union
from ..models.environmental_impact_dto_category import EnvironmentalImpactDtoCategory


T = TypeVar("T", bound="EnvironmentalImpactDto")


@_attrs_define
class EnvironmentalImpactDto:
    """
    Attributes:
        category (Union[Unset, EnvironmentalImpactDtoCategory]):  Default: EnvironmentalImpactDtoCategory.NUCLEAR_WASTE.
        amount (Union[Unset, int]):
    """

    category: Union[Unset, EnvironmentalImpactDtoCategory] = (
        EnvironmentalImpactDtoCategory.NUCLEAR_WASTE
    )
    amount: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        category: Union[Unset, str] = UNSET
        if not isinstance(self.category, Unset):
            category = self.category.value

        amount = self.amount

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if category is not UNSET:
            field_dict["category"] = category
        if amount is not UNSET:
            field_dict["amount"] = amount

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _category = d.pop("category", UNSET)
        category: Union[Unset, EnvironmentalImpactDtoCategory]
        if isinstance(_category, Unset) or _category is None:
            category = UNSET
        else:
            category = EnvironmentalImpactDtoCategory(_category)

        amount = d.pop("amount", UNSET)

        environmental_impact_dto = cls(
            category=category,
            amount=amount,
        )

        environmental_impact_dto.additional_properties = d
        return environmental_impact_dto

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
